==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/pl-PL/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Akcesorium zwrócono',
    'Accessory_Checkout_Notification' => 'Akcesoria zablokowane',
    'Asset_Checkin_Notification' => 'Sprzęt zwrócono',
    'Asset_Checkout_Notification' => 'Zasób wydany',
    'Confirm_Accessory_Checkin' => 'Potwierdź przyjęcie akcesorium',
    'Confirm_Asset_Checkin' => 'Potwierdź otrzymanie sprzętu',
    'Confirm_accessory_delivery' => 'Potwierdź otrzymanie akcesorium',
    'Confirm_asset_delivery' => 'Potwierdź otrzymanie sprzętu',
    'Confirm_consumable_delivery' => 'Potwierdź otrzymanie materiałów eksploatacyjnych',
    'Confirm_license_delivery' => 'Potwierdź otrzymanie licencji',
    'Consumable_checkout_notification' => 'Materiał eksploatacyjny został zablokowany',
    'Days' => 'Dni',
    'Expected_Checkin_Date' => 'Zasób przypisany Tobie ma być zwrócony w dniu :date',
    'Expected_Checkin_Notification' => 'Przypomnienie: :name sprawdza termin zbliżający się',
    'Expected_Checkin_Report' => 'Oczekiwano raportu kontroli aktywów',
    'Expiring_Assets_Report' => 'Raport wygasających sprzętów.',
    'Expiring_Licenses_Report' => 'Raport Wygasających Licencji.',
    'Item_Request_Canceled' => 'Anulowano zamówioną pozycję',
    'Item_Requested' => 'Pozycja Zamówiona',
    'License_Checkin_Notification' => 'Akcesorium zwrócono',
    'License_Checkout_Notification' => 'Licencja wyczyszczona',
    'Low_Inventory_Report' => 'Raport niskiego stanu zasobów',
    'a_user_canceled' => 'Użytkownik anulował zapotrzebowanie na sprzęt na stronie www',
    'a_user_requested' => 'Użytkownik zamówił pozycję na stronie internetowej',
    'acceptance_asset_accepted' => 'Użytkownik zaakceptował zasób',
    'acceptance_asset_declined' => 'Użytkownik odrzucił zasób',
    'accessory_name' => 'Nazwa akcesoriów',
    'additional_notes' => 'Dodatkowe notatki',
    'admin_has_created' => 'Administrator utworzył dla Ciebie konto na stronie :web.',
    'asset' => 'Aktywo',
    'asset_name' => 'Nazwa nabytku',
    'asset_requested' => 'Wystosowane zapotrzebowanie na sprzęt',
    'asset_tag' => 'Tag sprzętu',
    'assets_warrantee_alert' => 'Istnieje :count aktywów z gwarancją wygasającą w ciągu następnych :thereshold dni. | Istnieje :count aktywów z gwarancją wygasającą w ciągu następnych :threshold dni.',
    'assigned_to' => 'Przypisane do',
    'best_regards' => 'Pozdrawiam',
    'canceled' => 'Anulowane',
    'checkin_date' => 'Data przypisania',
    'checkout_date' => 'Data przypisania',
    'checkedout_from' => 'Zamówiono z',
    'checkedin_from'  => 'Sprawdzone od',
    'checked_into' => 'Sprawdzone w',
    'click_on_the_link_accessory' => 'Proszę kliknąć link poniżej aby potwierdzić otrzymanie sprzętu.',
    'click_on_the_link_asset' => 'Proszę kliknąć link poniżej aby potwierdzić otrzymanie sprzętu.',
    'click_to_confirm' => 'Proszę kliknąć na ten link aby potwierdzić swoje konto na :web:',
    'current_QTY' => 'Bieżąca ilość',
    'days' => 'Dni',
    'expecting_checkin_date' => 'Przewidywana data przyjęcia',
    'expires' => 'Wygasa',
    'hello' => 'Cześć',
    'hi' => 'Cześć',
    'i_have_read' => 'Przeczytałem i zgadzam się z warunkami użytkowania oraz potwierdzam otrzymanie niniejszej pozycji.',
    'inventory_report' => 'Raport z magazynu',
    'item' => 'Przedmiot',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Istnieje: liczba licencja wygasająca w ciągu następnych: dni progowe. | Istnieje: liczba licencji wygasających w ciągu następnych: dni progowe.',
    'link_to_update_password' => 'Proszę kliknąć na poniższy link, aby zaktualizować swoje hasło na :web:',
    'login' => 'Login:',
    'login_first_admin' => 'Zaloguj się do aplikacji Snipe-IT przy użyciu poniższych poświadczeń:',
    'low_inventory_alert' => 'Istnieje: liczba przedmiot, który jest poniżej minimalnej ilości zapasów lub wkrótce ta wartość będzie niska. | Istnieją: policz przedmioty, które są poniżej minimalnej ilości zapasów lub wkrótce te wartości będą niskie.',
    'min_QTY' => 'Min. ilość',
    'name' => 'Nazwa',
    'new_item_checked' => 'Nowy przedmiot przypisany do Ciebie został zwrócony, szczegóły poniżej.',
    'notes' => 'Uwagi',
    'password' => 'Hasło',
    'password_reset' => 'Resetowanie hasła',
    'read_the_terms' => 'Proszę przeczytać warunki użytkowania przedstawione poniżej.',
    'read_the_terms_and_click' => 'Proszę zapoznać się z poniższymi warunkami użycia, i kliknij na link na dole, aby potwierdzić, że przeczytałeś/aś i zgodzisz się na warunki użytkowania i otrzymałeś/aś aktywa.',
    'requested' => 'Wymagane',
    'reset_link' => 'Link resetujący Twoje hasło',
    'reset_password' => 'Kliknij tutaj aby zresetować swoje hasło:',
    'rights_reserved' => 'Wszystkie prawa zastrzeżone.',
    'serial' => 'Nr seryjny',
    'snipe_webhook_test' => 'Test integracji Snipe-IT',
    'snipe_webhook_summary' => 'Podsumowanie testu integracji Snipe-IT',
    'supplier' => 'Dostawca',
    'tag' => 'Tag',
    'test_email' => 'Testowy email z :web',
    'test_mail_text' => 'To jest wiadomość testowa z aplikacji Snipe-IT Asset Management System. Jeśli otrzymałeś ją - poczta działa :)',
    'the_following_item' => 'Następujący sprzęt został otrzymany: ',
    'to_reset' => 'Aby zresetować hasło na :web, wypełnij ten formularz:',
    'type' => 'Typ',
    'upcoming-audits' => 'Istnieje :count aktywa, które nadchodzą do rewizji w ciągu :threshold days.|Istnieje :count aktywów, które nadchodzą do rewizji w ciągu :threshold dni.',
    'user' => 'Użytkownik',
    'username' => 'Nazwa użytkownika',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Witaj :name',
    'welcome_to' => 'Witamy na :web!',
    'your_assets' => 'Zobacz swój sprzęt',
    'your_credentials' => 'Twoje poświadczenia :web',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/pl-PL/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Akcesorium zwrócono',
    'Accessory_Checkout_Notification' => 'Akcesoria zablokowane',
    'Asset_Checkin_Notification' => 'Sprzęt zwrócono',
    'Asset_Checkout_Notification' => 'Zasób wydany',
    'Confirm_Accessory_Checkin' => 'Potwierdź przyjęcie akcesorium',
    'Confirm_Asset_Checkin' => 'Potwierdź otrzymanie sprzętu',
    'Confirm_accessory_delivery' => 'Potwierdź otrzymanie akcesorium',
    'Confirm_asset_delivery' => 'Potwierdź otrzymanie sprzętu',
    'Confirm_consumable_delivery' => 'Potwierdź otrzymanie materiałów eksploatacyjnych',
    'Confirm_license_delivery' => 'Potwierdź otrzymanie licencji',
    'Consumable_checkout_notification' => 'Materiał eksploatacyjny został zablokowany',
    'Days' => 'Dni',
    'Expected_Checkin_Date' => 'Zasób przypisany Tobie ma być zwrócony w dniu :date',
    'Expected_Checkin_Notification' => 'Przypomnienie: :name sprawdza termin zbliżający się',
    'Expected_Checkin_Report' => 'Oczekiwano raportu kontroli aktywów',
    'Expiring_Assets_Report' => 'Raport wygasających sprzętów.',
    'Expiring_Licenses_Report' => 'Raport Wygasających Licencji.',
    'Item_Request_Canceled' => 'Anulowano zamówioną pozycję',
    'Item_Requested' => 'Pozycja Zamówiona',
    'License_Checkin_Notification' => 'Akcesorium zwrócono',
    'License_Checkout_Notification' => 'Licencja wyczyszczona',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Raport niskiego stanu zasobów',
    'a_user_canceled' => 'Użytkownik anulował zapotrzebowanie na sprzęt na stronie www',
    'a_user_requested' => 'Użytkownik zamówił pozycję na stronie internetowej',
    'acceptance_asset_accepted' => 'Użytkownik zaakceptował zasób',
    'acceptance_asset_declined' => 'Użytkownik odrzucił zasób',
    'accessory_name' => 'Nazwa akcesoriów',
    'additional_notes' => 'Dodatkowe notatki',
    'admin_has_created' => 'Administrator utworzył dla Ciebie konto na stronie :web.',
    'asset' => 'Aktywo',
    'asset_name' => 'Nazwa nabytku',
    'asset_requested' => 'Wystosowane zapotrzebowanie na sprzęt',
    'asset_tag' => 'Tag sprzętu',
    'assets_warrantee_alert' => 'Istnieje :count aktywów z gwarancją wygasającą w ciągu następnych :thereshold dni. | Istnieje :count aktywów z gwarancją wygasającą w ciągu następnych :threshold dni.',
    'assigned_to' => 'Przypisane do',
    'best_regards' => 'Pozdrawiam',
    'canceled' => 'Anulowane',
    'checkin_date' => 'Data przypisania',
    'checkout_date' => 'Data przypisania',
    'checkedout_from' => 'Zamówiono z',
    'checkedin_from'  => 'Sprawdzone od',
    'checked_into' => 'Sprawdzone w',
    'click_on_the_link_accessory' => 'Proszę kliknąć link poniżej aby potwierdzić otrzymanie sprzętu.',
    'click_on_the_link_asset' => 'Proszę kliknąć link poniżej aby potwierdzić otrzymanie sprzętu.',
    'click_to_confirm' => 'Proszę kliknąć na ten link aby potwierdzić swoje konto na :web:',
    'current_QTY' => 'Bieżąca ilość',
    'days' => 'Dni',
    'expecting_checkin_date' => 'Przewidywana data przyjęcia',
    'expires' => 'Wygasa',
    'hello' => 'Cześć',
    'hi' => 'Cześć',
    'i_have_read' => 'Przeczytałem i zgadzam się z warunkami użytkowania oraz potwierdzam otrzymanie niniejszej pozycji.',
    'inventory_report' => 'Raport z magazynu',
    'item' => 'Przedmiot',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Istnieje: liczba licencja wygasająca w ciągu następnych: dni progowe. | Istnieje: liczba licencji wygasających w ciągu następnych: dni progowe.',
    'link_to_update_password' => 'Proszę kliknąć na poniższy link, aby zaktualizować swoje hasło na :web:',
    'login' => 'Login',
    'login_first_admin' => 'Zaloguj się do aplikacji Snipe-IT przy użyciu poniższych poświadczeń:',
    'low_inventory_alert' => 'Istnieje: liczba przedmiot, który jest poniżej minimalnej ilości zapasów lub wkrótce ta wartość będzie niska. | Istnieją: policz przedmioty, które są poniżej minimalnej ilości zapasów lub wkrótce te wartości będą niskie.',
    'min_QTY' => 'Min. ilość',
    'name' => 'Nazwa',
    'new_item_checked' => 'Nowy przedmiot został przypisany do Ciebie, szczegóły poniżej.',
    'notes' => 'Uwagi',
    'password' => 'Hasło',
    'password_reset' => 'Resetowanie hasła',
    'read_the_terms' => 'Proszę przeczytać warunki użytkowania przedstawione poniżej.',
    'read_the_terms_and_click' => 'Proszę zapoznać się z poniższymi warunkami użycia, i kliknij na link na dole, aby potwierdzić, że przeczytałeś/aś i zgodzisz się na warunki użytkowania i otrzymałeś/aś aktywa.',
    'requested' => 'Wymagane',
    'reset_link' => 'Link resetujący Twoje hasło',
    'reset_password' => 'Kliknij tutaj aby zresetować swoje hasło:',
    'rights_reserved' => 'Wszystkie prawa zastrzeżone.',
    'serial' => 'Nr seryjny',
    'snipe_webhook_test' => 'Test integracji Snipe-IT',
    'snipe_webhook_summary' => 'Podsumowanie testu integracji Snipe-IT',
    'supplier' => 'Dostawca',
    'tag' => 'Tag',
    'test_email' => 'Testowy email z :web',
    'test_mail_text' => 'To jest wiadomość testowa z aplikacji Snipe-IT Asset Management System. Jeśli otrzymałeś ją - poczta działa :)',
    'the_following_item' => 'Następujący sprzęt został otrzymany: ',
    'to_reset' => 'Aby zresetować hasło na :web, wypełnij ten formularz:',
    'type' => 'Typ',
    'upcoming-audits' => 'Istnieje :count aktywa, które nadchodzą do rewizji w ciągu :threshold days.|Istnieje :count aktywów, które nadchodzą do rewizji w ciągu :threshold dni.',
    'user' => 'Użytkownik',
    'username' => 'Nazwa użytkownika',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Witaj :name',
    'welcome_to' => 'Witamy na :web!',
    'your_assets' => 'Zobacz swój sprzęt',
    'your_credentials' => 'Twoje poświadczenia :web',
    'mail_sent' => 'Wiadomość wysłana pomyślnie!',
];
